%global with_doc 0
%global pypi_name ceilometer

Summary:          OpenStack measurement collection service
Name:             openstack-ceilometer
Version:          16.0.0
Release:          2%{?dist}
License:          ASL 2.0
URL:              https://wiki.openstack.org/wiki/Ceilometer
Source0:          https://tarballs.openstack.org/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
Source1:          %{pypi_name}-dist.conf
Source2:          %{pypi_name}.logrotate
Source3:          ceilometer-rootwrap-sudoers
Source11:         %{name}-compute.service
Source12:         %{name}-central.service
Source13:         %{name}-notification.service
Source14:         %{name}-ipmi.service
Source15:         %{name}-polling.service

BuildRequires:    python3-devel python3-babel python3-setuptools
BuildRequires:    python3-cotyledon python3-sphinx python3-pbr >= 1.10.0
BuildRequires:    git-core intltool systemd

BuildArch:        noarch

%description
OpenStack ceilometer provides services to measure and collect metrics from OpenStack components.

%package -n       python3-ceilometer
Summary:          OpenStack ceilometer python libraries

Requires:         python3-cachetools >= 2.1.0 python3-eventlet python3-futurist >= 1.8.0
Requires:         python3-keystoneauth1 >= 3.18.0 python3-jsonpath-rw-ext python3-stevedore >= 1.20.0
Requires:         python3-pbr python3-tenacity >= 4.12.0 python3-oslo-config >= 6.0.0 python3-netaddr
Requires:         python3-oslo-rootwrap >= 2.0.0 python3-oslo-vmware >= 0.6.0 python3-requests >= 2.8.1
Requires:         python3-oslo-concurrency >= 3.26.0 python3-oslo-i18n  >= 3.15.3 python3-pysnmp
Requires:         python3-oslo-log  >= 3.36.0 python3-oslo-privsep >= 1.32.0 python3-yaml >= 5.1
Requires:         python3-oslo-reports >= 1.18.0 python3-oslo-upgradecheck >= 0.1.1 python3-lxml
Requires:         python3-oslo-cache >= 1.26.0 python3-monascaclient >= 1.12.0 python3-jsonpath-rw
Requires:         python3-msgpack >= 0.5.2 python3-monotonic >= 0.6 python3-cotyledon


%description -n   python3-ceilometer
This package provides the ceilometer python library.


%package common
Summary:          Components common to all OpenStack ceilometer services

BuildRequires:    python3-os-xenapi python3-oslo-config >= 6.0.0 python3-oslo-concurrency
BuildRequires:    python3-oslo-log python3-oslo-messaging python3-oslo-privsep python3-tooz
BuildRequires:    python3-oslo-reports python3-oslo-vmware >= 0.6.0 python3-glanceclient >= 2.8.0
BuildRequires:    python3-neutronclient python3-novaclient  >= 9.1.0 python3-swiftclient
BuildRequires:    python3-jsonpath-rw-ext python3-gnocchiclient >= 7.0.0
BuildRequires:    python3-cinderclient >= 3.3.0 python3-zaqarclient >= 1.3.0
BuildRequires:    python3-jsonpath-rw python3-lxml python3-monotonic >= 0.6
Requires:         python3-ceilometer = %{version}-%{release}
Requires:         python3-oslo-messaging >= 8.0.0 python3-oslo-utils >= 3.37.0 python3-tooz
Requires:         python3-gnocchiclient >= 7.0.0 python3-os-xenapi >= 0.3.3
Requires:         python3-novaclient >= 9.1.0 python3-keystoneclient >= 3.18.0
Requires:         python3-neutronclient >= 6.7.0 python3-glanceclient >= 2.8.0
Requires:         python3-swiftclient python3-cinderclient >= 3.3.0 python3-zaqarclient >= 1.3.0
%{?systemd_ordering} 
Requires(pre):    shadow-utils
Provides:         openstack-ceilometer-collector = %{version}-%{release}
Obsoletes:        openstack-ceilometer-collector < %{version}-%{release}

%description common
This package provides components common to all OpenStack ceilometer services.


%package compute
Summary:          OpenStack ceilometer compute agent

Requires:         %{name}-common = %{version}-%{release}
Requires:         %{name}-polling = %{version}-%{release}
Requires:         python3-libvirt


%description compute
This package provides the ceilometer agent for running on OpenStack compute nodes.


%package central
Summary:          OpenStack ceilometer central agent

Requires:         %{name}-common = %{version}-%{release}
Requires:         %{name}-polling = %{version}-%{release}

%description central
This package provides the central ceilometer agent.


%package notification
Summary:          OpenStack ceilometer notification agent

Requires:         %{name}-common = %{version}-%{release}

%description notification
This package provides the ceilometer notification agent which pushes metrics to the collector 
service from the various OpenStack services.


%package ipmi
Summary:          OpenStack ceilometer ipmi agent

Requires:         %{name}-common = %{version}-%{release}
Requires:         %{name}-polling = %{version}-%{release}
Requires:         ipmitool

%description ipmi
This package provides the ipmi agent to be run on OpenStack nodes from which IPMI sensor data is 
to be collected directly, by-passing the Ironic management of baremetal.


%package polling
Summary:          OpenStack ceilometer polling agent

Requires:         %{name}-common = %{version}-%{release}
Requires:         python3-libvirt

%description polling
This package provides the polling service.

%package -n python3-ceilometer-tests
Summary:        Ceilometer tests
Requires:       python3-ceilometer = %{version}-%{release}
Requires:       python3-gabbi >= 1.30.0

%description -n python3-ceilometer-tests
This package provides the Ceilometer test files.

%if 0%{?with_doc}
%package doc
Summary:          Documentation for OpenStack ceilometer

BuildRequires:    python3-eventlet python3-openstackdocstheme
BuildRequires:    python3-iso8601

%description      doc
This package provides documentation files for ceilometer.
%endif

%prep
%autosetup -n ceilometer-%{version} -S git

find . \( -name .gitignore -o -name .placeholder \) -delete
find ceilometer -name \*.py -exec sed -i '/\/usr\/bin\/env python/{d;q}' {} +

sed -i '/setup_requires/d; /install_requires/d; /dependency_links/d' setup.py

# ipmort fnmatch module from stdlib due to the python3-oslo-utils upgrade
sed -i 's/from oslo_utils import fnmatch/import fnmatch/g' ceilometer/agent.py
sed -i 's/from oslo_utils import fnmatch/import fnmatch/g' ceilometer/event/converter.py
sed -i 's/from oslo_utils import fnmatch/import fnmatch/g' ceilometer/publisher/gnocchi.py

rm -rf *requirements.txt

%build
PYTHONPATH=. oslo-config-generator --config-file=etc/ceilometer/ceilometer-config-generator.conf

%{py3_build}

# generate the i18n files
%{__python3} setup.py compile_catalog -d build/lib/%{pypi_name}/locale --domain ceilometer

# update defaults in sample config which is installed at /etc/ceilometer/ceilometer.conf
while read name eq value; do
  test "$name" && test "$value" || continue
  sed -i "0,/^# *$name=/{s!^# *$name=.*!#$name=$value!}" etc/ceilometer/ceilometer.conf
done < %{SOURCE1}

%install
%{py3_install}

%if 0%{?with_doc}

%{py3_build}
# fix hidden file/dir warnings
rm -fr doc/build/html/.doctrees doc/build/html/.buildinfo

%endif

install -d -m 755 %{buildroot}%{_sharedstatedir}/ceilometer
install -d -m 755 %{buildroot}%{_sharedstatedir}/ceilometer/tmp
install -d -m 750 %{buildroot}%{_localstatedir}/log/ceilometer

# install config files
install -d -m 755 %{buildroot}%{_sysconfdir}/ceilometer
install -d -m 755 %{buildroot}%{_sysconfdir}/ceilometer/rootwrap.d
install -d -m 755 %{buildroot}%{_sysconfdir}/sudoers.d
install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 755 %{buildroot}%{_sysconfdir}/ceilometer/meters.d
install -p -D -m 640 %{SOURCE1} %{buildroot}%{_datadir}/ceilometer/ceilometer-dist.conf
install -p -D -m 440 %{SOURCE3} %{buildroot}%{_sysconfdir}/sudoers.d/ceilometer
install -p -D -m 640 etc/ceilometer/ceilometer.conf %{buildroot}%{_sysconfdir}/ceilometer/ceilometer.conf
install -p -D -m 640 ceilometer/pipeline/data/pipeline.yaml %{buildroot}%{_sysconfdir}/ceilometer/pipeline.yaml
install -p -D -m 640 etc/ceilometer/polling.yaml %{buildroot}%{_sysconfdir}/ceilometer/polling.yaml
install -p -D -m 640 ceilometer/pipeline/data/event_pipeline.yaml %{buildroot}%{_sysconfdir}/ceilometer/event_pipeline.yaml
install -p -D -m 640 ceilometer/pipeline/data/event_definitions.yaml %{buildroot}%{_sysconfdir}/ceilometer/event_definitions.yaml
install -p -D -m 640 etc/ceilometer/rootwrap.conf %{buildroot}%{_sysconfdir}/ceilometer/rootwrap.conf
install -p -D -m 640 etc/ceilometer/rootwrap.d/ipmi.filters %{buildroot}/%{_sysconfdir}/ceilometer/rootwrap.d/ipmi.filters
install -p -D -m 640 ceilometer/publisher/data/gnocchi_resources.yaml %{buildroot}%{_sysconfdir}/ceilometer/gnocchi_resources.yaml
install -p -D -m 640 ceilometer/data/meters.d/meters.yaml %{buildroot}%{_sysconfdir}/ceilometer/meters.d/meters.yaml

# install systemd units
install -p -D -m 644 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}-compute.service
install -p -D -m 644 %{SOURCE12} %{buildroot}%{_unitdir}/%{name}-central.service
install -p -D -m 644 %{SOURCE13} %{buildroot}%{_unitdir}/%{name}-notification.service
install -p -D -m 644 %{SOURCE14} %{buildroot}%{_unitdir}/%{name}-ipmi.service
install -p -D -m 644 %{SOURCE15} %{buildroot}%{_unitdir}/%{name}-polling.service

# install logrotate file
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# install i18n .mo files (except .po and .pot)
install -d -m 755 %{buildroot}%{_datadir}
rm -f %{buildroot}%{python3_sitelib}/%{pypi_name}/locale/*/LC_*/%{pypi_name}*po
rm -f %{buildroot}%{python3_sitelib}/%{pypi_name}/locale/*pot
mv %{buildroot}%{python3_sitelib}/%{pypi_name}/locale %{buildroot}%{_datadir}/locale

rm -f %{buildroot}/usr/share/doc/ceilometer/README*
rm -fr %{buildroot}/usr/etc

%find_lang %{pypi_name} --all-name

%pre common
getent group ceilometer >/dev/null || groupadd -r ceilometer --gid 166
if ! getent passwd ceilometer >/dev/null; then
  useradd -u 166 -r -g ceilometer -G ceilometer,nobody -d %{_sharedstatedir}/ceilometer -s /sbin/nologin -c "OpenStack ceilometer Daemons" ceilometer
fi
exit 0

%post compute
%systemd_post %{name}-compute.service

%post notification
%systemd_post %{name}-notification.service

%post central
%systemd_post %{name}-central.service

%post ipmi
%systemd_post %{name}-alarm-ipmi.service

%post polling
%systemd_post %{name}-polling.service

%preun compute
%systemd_preun %{name}-compute.service

%preun notification
%systemd_preun %{name}-notification.service

%preun central
%systemd_preun %{name}-central.service

%preun ipmi
%systemd_preun %{name}-ipmi.service

%preun polling
%systemd_preun %{name}-polling.service

%postun compute
%systemd_postun_with_restart %{name}-compute.service

%postun notification
%systemd_postun_with_restart %{name}-notification.service

%postun central
%systemd_postun_with_restart %{name}-central.service

%postun ipmi
%systemd_postun_with_restart %{name}-ipmi.service

%postun polling
%systemd_postun_with_restart %{name}-polling.service


%files common -f %{pypi_name}.lang
%license LICENSE
%dir %{_sysconfdir}/ceilometer
%attr(-, root, ceilometer) %{_datadir}/ceilometer/ceilometer-dist.conf
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/ceilometer.conf
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/pipeline.yaml
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/polling.yaml
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/gnocchi_resources.yaml
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/ceilometer-send-sample
%{_bindir}/ceilometer-upgrade
%{_bindir}/ceilometer-status
%dir %attr(0750, ceilometer, root) %{_localstatedir}/log/ceilometer
%defattr(-, ceilometer, ceilometer, -)
%dir %{_sharedstatedir}/ceilometer
%dir %{_sharedstatedir}/ceilometer/tmp


%files -n python3-ceilometer
%{python3_sitelib}/ceilometer
%{python3_sitelib}/ceilometer-*.egg-info
%exclude %{python3_sitelib}/ceilometer/tests


%files -n python3-ceilometer-tests
%license LICENSE
%{python3_sitelib}/ceilometer/tests


%if 0%{?with_doc}
%files doc
%doc doc/build/html
%endif


%files compute
%{_unitdir}/%{name}-compute.service


%files notification
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/event_pipeline.yaml
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/event_definitions.yaml
%dir %{_sysconfdir}/ceilometer/meters.d
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/meters.d/meters.yaml
%{_bindir}/ceilometer-agent-notification
%{_unitdir}/%{name}-notification.service


%files central
%{_unitdir}/%{name}-central.service


%files ipmi
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/rootwrap.conf
%config(noreplace) %attr(-, root, ceilometer) %{_sysconfdir}/ceilometer/rootwrap.d/ipmi.filters
%{_sysconfdir}/sudoers.d/ceilometer
%{_bindir}/ceilometer-rootwrap
%{_unitdir}/%{name}-ipmi.service


%files polling
%{_bindir}/ceilometer-polling
%{_unitdir}/%{name}-polling.service


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 16.0.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 13 2023 Wang Guodong <gordonwwang@tencent.com> - 16.0.0-1
- initial build
